@@ -4,14 +4,11 @@ parser = argparse.ArgumentParser()
 
 subparsers = parser.add_subparsers()
 
-my_command1 = subparsers.add_parser(
-    'apply', help='Execute provision script, collect all resources and apply them.'
-)
+my_command1 = subparsers.add_parser('apply', help='Execute provision script, collect all resources and apply them.')
 
 my_command1.add_argument(
     'path',
-    help='Specify path to provision script. provision.py in current'
-    'directory by default. Also may include url.',
+    help='Specify path to provision script. provision.py in current' 'directory by default. Also may include url.',
     default='provision.py',
 )
 my_command1.add_argument(
@@ -21,15 +18,9 @@ my_command1.add_argument(
     default=False,
     help='If specified will rollback all' 'resources applied.',
 )
-my_command1.add_argument(
-    '--tree', action='store_true', default=False, help='Print resource tree'
-)
-my_command1.add_argument(
-    '--dry', action='store_true', default=False, help='Just print changes list'
-)
-my_command1.add_argument(
-    '--force', action='store_true', default=False, help='Apply without confirmation'
-)
+my_command1.add_argument('--tree', action='store_true', default=False, help='Print resource tree')
+my_command1.add_argument('--dry', action='store_true', default=False, help='Just print changes list')
+my_command1.add_argument('--force', action='store_true', default=False, help='Apply without confirmation')
 my_command1.add_argument(
     'default_string',
     default='I am a default',
@@ -37,12 +28,8 @@ my_command1.add_argument(
 )
 
 my_command2 = subparsers.add_parser('game', help='Decision games')
-my_command2.add_argument(
-    'move', choices=['rock', 'paper', 'scissors'], help='Choices for argument example'
-)
-my_command2.add_argument(
-    '--opt', choices=['rock', 'paper', 'scissors'], help='Choices for option example'
-)
+my_command2.add_argument('move', choices=['rock', 'paper', 'scissors'], help='Choices for argument example')
+my_command2.add_argument('--opt', choices=['rock', 'paper', 'scissors'], help='Choices for option example')
 
 optional = my_command2.add_argument_group('Group 1')
 
